/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.apio.internal.architect.logger;

import com.liferay.apio.architect.error.APIError;
import com.liferay.apio.architect.logger.ApioLogger;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.Validator;

import java.util.Optional;

import org.osgi.service.component.annotations.Component;

/**
 * @author Alejandro Hernández
 */
@Component(immediate = true)
public class ApioLoggerImpl implements ApioLogger {

	@Override
	public void error(APIError apiError) {
		if (_log.isDebugEnabled()) {
			_log.debug(_getExceptionMessage(apiError), apiError.getException());
		}
		else {
			_log.error(_getExceptionMessage(apiError));
		}
	}

	@Override
	public void warning(String message) {
		if (_log.isDebugEnabled()) {
			_log.debug(message);
		}
		else {
			_log.warn(message);
		}
	}

	private String _getExceptionMessage(APIError apiError) {
		Optional<String> optional = apiError.getDescription();

		return optional.orElseGet(
			() -> {
				Exception exception = apiError.getException();

				String message = exception.getMessage();

				if (Validator.isNotNull(message)) {
					return message;
				}

				return apiError.toString();
			});
	}

	private static final Log _log = LogFactoryUtil.getLog(ApioLoggerImpl.class);

}